@@ -1,4 +1,4 @@
-/* Copyright 2003 gnome-vfsmm Development Team
+/* Copyright 2003, 2006 gnome-vfsmm Development Team
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -15,7 +15,7 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <libgnomevfsmm/async.h>
+#include <libgnomevfsmm/async-2.h>
 #include <libgnomevfs/gnome-vfs-job-limit.h>
 
 namespace Gnome
@@ -29,12 +29,12 @@ namespace Async
 
 void set_job_limit(int limit)
 {
-  gnome_vfs_async_set_job_limit(limit);
+  Async2::set_job_limit(limit);
 }
 
 int get_job_limit()
 {
-  return gnome_vfs_async_get_job_limit();
+  return Async2::get_job_limit();
 }
 
 } //namespace Async
